#
# spec file for package packetdrill
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           packetdrill
Version:        2.0+git.20241204
Release:        1.2
Summary:        Testing tool for kernel networking stack
License:        GPL-2.0-only
URL:            https://github.com/google/packetdrill
Source:         %{name}-%{version}.tar.gz
Patch99:        make-build-more-consistent-with-openSUSE-packaging.patch
BuildRequires:  bison
BuildRequires:  flex

%description
The packetdrill scripting tool enables quick, precise tests for entire
TCP/UDP/IPv4/IPv6 network stacks, from the system call layer down to the
NIC hardware. packetdrill currently works on Linux, FreeBSD, OpenBSD, and
NetBSD. It can test network stack behavior over physical NICs on a LAN, or
on a single machine using a tun virtual network device.

%package tests
Summary:        Sample test scripts for packetdrill
BuildArch:      noarch

%description tests
Collection of sample test scripts from Google for packetdrill utility.

%prep
%autosetup -p1

%build
cd gtests/net/packetdrill
CFLAGS="%{optflags} -Wall -Wno-unused-result -Wno-address-of-packed-member -Werror"
%configure
%make_build

%check
cd gtests/net/packetdrill
%make_build tests

%install
cd gtests/net/packetdrill
mkdir -p %{buildroot}%{_bindir}
install packetdrill %{buildroot}%{_bindir}/
find tests/linux -name '*.pkt' -exec chmod 644 {} \;
mkdir -p %{buildroot}%{_datadir}/%{name}
cp -r tests/linux/* %{buildroot}%{_datadir}/%{name}

%files
%license LICENSE
%doc README.md
%{_bindir}/packetdrill

%files tests
%{_datadir}/%{name}

%changelog
* Tue Dec 10 2024 Martin Pluskal <mpluskal@suse.com>
- Update to version 2.0+git.20241204:
  * net-test: mss value change for tcp setsockopt mss
* Tue Jul 30 2024 Martin Pluskal <mpluskal@suse.com>
- Update to version 2.0+git.20240726:
  * net-test: new behaviour change for simult TFO connect
  * net-test: behaviour change for simultaneous TFO connect
  * net-test: packetdrill: run_all: add --dry_run mode
  * net-test: packetdrill: run_all: add --capture option
  * net-test: packetdrill: run_all: extra -v are passed to pktdrill cmd
  * net-test: packetdrill: run_all: support timeout with --serialized
  * net-test: packetdrill: run_all: limit tests running in parallel
  * net-test: packetdrill: ensure --wire_client and --wire_server cancel opposing flags
  * Revert "net-test: packetdrill: bug fix: wire_server must ignore new --wire_server_at arg"
  * net-test: packetdrill: bug fix: wire_server must ignore new --wire_server_at arg
* Tue Jun 13 2023 Martin Pluskal <mpluskal@suse.com>
- Update to version 2.0+git.20230521:
  * net-test: packetdrill: add README.md details about IP addresses for test traffic
  * net-test: packetdrill: update README.md to add docs for local and remote mode
  * net-test: packetdrill: DEBUGP() for looking up non-TCP sockets in wire tests
  * net-test: packetdrill: fix crash with --debug in run_syscall_accept()
  * net-test: packetdrill: add debugging for live_local_ip_string
  * net-test: packetdrill: invoke set_default_config() before parse_script_and_set_config()
  * net-test: packetdrill: have wire_client send live_local_ip_string to wire_server
  * net-test: packetdrill: default wire client to using real IP of client and server machines
  * net-test: packetdrill: make --wire_server_at or --wire_server_ip imply --wire_client
  * net-test: packetdrill: introduce --wire_server_at as a synonym for --wire_server_ip
- Drop no longer needed patches:
  * net-test-packetdrill-allow-any-size-for-TCP_INFO-and.patch
  * net-test-packetdrill-define-Linux-capability-symbols.patch
  * net-test-packetdrill-fix-error-msg-in-loose-segment-.patch
  * net-test-packetdrill-loose-segmentation-checks-non-s.patch
* Thu Jul 11 2019 Michal Kubeček <mkubecek@suse.cz>
- suppress "address of packed member" gcc9 warning (fix Factory
  build)
- add useful post-2.0 upstream commits:
  net-test-packetdrill-allow-any-size-for-TCP_INFO-and.patch
  net-test-packetdrill-define-Linux-capability-symbols.patch
  net-test-packetdrill-loose-segmentation-checks-non-s.patch
  net-test-packetdrill-fix-error-msg-in-loose-segment-.patch
- no longer need to define CAP_BLOCK_SUSPEND for SLE11 build
* Wed Apr 25 2018 mkubecek@suse.cz
- make-build-more-consistent-with-openSUSE-packaging.patch:
  tweak the makefiles to be consistent with openSUSE policies
* Wed Apr 25 2018 mkubecek@suse.cz
- initial import of 2.0 sources
